# This file was auto-generated by Fern from our API Definition.

import typing
from .cost_function import CostFunction
from .parameter_constraint import ParameterConstraint

Statement = typing.Union[CostFunction, ParameterConstraint]
